function [DF] = iDF_Cauchy_Riemann(x,lambda)

% Computes the Jacobian of Cauchy-Riemann with Intlab

%%%
%%% INPUT for F_Cauchy_Riemann: x=(a,b) in R^{2m}
%%% (1) lambda: parameter
%%% (2) a=(a0,a1,a2,...,a_{m-1}): vector of cosine Fourier coefficients of the function u(x)
%%% (3) b=(b0,b1,b2,...,b_{m-1}): vector of sine Fourier coefficients of the function v(x)
%%%
%%% OUTPUT for DF_Cauchy_Riemann: DF_{k,j}=[DF1_k/Da_j DF1_k/Db_j ; DF2_k/Da_j DF3_k/Db_j]
%%% Four mxm matrices

m = length(x)/2;

a=x(1:m); %%% Cosine Fourier expansion of the function v(x)
k=(0:m-1)';

temp_a2 = int_quadratic_sumFFT(intval([a;zeros(m,1)]),intval([a;zeros(m,1)]));
a2 = [flip(temp_a2(2:m));temp_a2(1:end-1)];

non_linear_Df_Da = intval(zeros(m));

non_linear_Df_Da(:,1) = -3*lambda*(a2(k+m));

for j=1:m-1
    %%% Dg_k/Da_j %%%
    non_linear_Df_Da(:,j+1)=-3*lambda*(a2(k-j+m)+a2(k+j+m));
end

Df_Da = lambda*eye(m)+non_linear_Df_Da;
Df_Db = -intval(diag(k));
Dg_Da = -intval(diag(k));
Dg_Db = intval(eye(m));

DF = [[Df_Da Df_Db];[Dg_Da Dg_Db]];

end