function [F]=iF_Cauchy_Riemann(x,lambda)

% Computes the map of Cauchy-Riemann with Intlab

%%%
%%% INPUT for F_Cauchy_Riemann: x=(a,b) in R^{2m}
%%% (1) lambda: parameter
%%% (2) a=(a0,a1,a2,...,a_{m-1}): vector of cosine Fourier coefficients of the function u(x)
%%% (3) b=(b0,b1,b2,...,b_{m-1}): vector of sine Fourier coefficients of the function v(x)
%%%
%%% OUTPUT for F_Cauchy_Riemann: F=(f,g) in R^{2m}
%%% (1) F1=(F1_0,F1_1,F1_2,...,F1_{m-1})
%%% (2) F2=(F2_0,F2_1,F2_2,...,F2_{m-1})

m=length(x)/2;

a=x(1:m); %%% Cosine Fourier expansion of the function v(x)
b=x(m+1:2*m);   %%% Sine Fourier expansion of the function u(x) 
k=(0:m-1)';

a3=int_cubic_sumFFT(a,a,a);

F1=-k.*b+lambda*(a-a3);
F2=-k.*a+b;

F = [F1;F2];

end