function [Eigs,rad_pol]=verify_the_eigs(iA)

%%% This code takes an interval matrix (possibly of radius 0), computes its
%%% eigendecomposition using the "eig" function in MATLAB, and then
%%% validates the existence of each eigenpair (v,lambda) of the nonlinear
%%% problem iA*v-lambda*v=0. It does so using the radii polynomials. If
%%% successful, the code returns the list of eigenvalues Eigs together
%%% with the radius enclosing them. Hence, the interval
%%% [Eigs(k)-rad_pol,Eigs(k)+rad_pol] constains a unique eigenvalue

A=mid(iA);

[V,D]=eig(A);
Eigs=diag(D);
N=length(Eigs);

X=zeros(N);
y=zeros(2*N,N);
BVK=zeros(N);
index_k=zeros(1,N);
for j=1:N
    [p,k]=max(abs(V(:,j)));
    index_k(j)=k;
    BVK(j)=V(k,j);
    X(:,j)=[D(j,j);V(1:k-1,j);V(k+1:end,j)];
    y(:,j)=[real(X(:,j));imag(X(:,j))];
end

rad_pol=zeros(1,N);

for j=1:N
    rad_pol(j)=enc_eig(iA,V(:,j),Eigs(j));
end

end